import { LocalTrackOptions } from '../track/options';
/**
 * CreateLocalMediaOptions provide a way to configure local user media.
 *
 * These options are for use with [[getUserMedia]] and [[getDisplayMedia]].
 *
 * For example, if you want a users video but not audio:
 * ```typescript
 * getUserMedia({video: true});
 * ```
 * This will return you a [[LocalTrack]] with a [[LocalTrack.source]] of [[TrackSource.Camera]] and
 * a [[LocalTrack.kind]] of [[TrackKind.Video]].
 *
 * If you wanted a user's audio but not video:
 * ```typescript
 * getUserMedia({audio: true});
 * ```
 * This will return you a [[LocalTrack]] with a [[LocalTrack.source]] of [[TrackSource.Microphone]] and
 * a [[LocalTrack.kind]] of [[TrackKind.Audio]].
 *
 *
 * If you want video and audio with specific deviceIds:
 * ```typescript
 * getUserMedia({
 *     audio: {deviceId: {exact: AUDIO_DEVICE_ID}}
 *     video: {deviceId: {exact: VIDEO_DEVICE_ID}}
 *  });
 *```

 * You may also specify a `name` to be used for a [[LocalTrack]], so it may appear on the [[RemoteTrack.name]]
 * property for the [[RemoteParticipant]].
 * ```typescript
 * getUserMedia({
 *     audio: {name: 'Named Microphone'}
 *     video: {name: 'Named Webcam'}
 *  });
 * ```
 */
export interface CreateLocalMediaOptions {
    /**
     * options for configuring local audio
     */
    audio?: LocalTrackOptions | boolean;
    /**
     * options for configuring local video
     */
    video?: LocalTrackOptions | boolean;
}
