/**
 * Options available for configuring a {@link Space}.
 */
export interface SpaceOptionsParams {
    /**
     * Disable ABR publishing which means the participant will only publish 1 rendition of their video to the server.
     * This will lower CPU and bandwidth usage but can lead to poor performance in Spaces with more than 10 people.
     */
    disableABRPublishing?: boolean;
    /**
     * Disable automatic subscriptions. If this is true the participant will not automatically be subscribed to remote
     * media sources. Instead a call to `RemoteParticipant.subscribe()` will be needed before the local participant will
     * receive media.
     */
    subscriptionMode?: SubscriptionMode;
    /**
     * Sets the participant limit to be used if `subscriptionMode` is set to `SubscriptionMode.Automatic`.
     * This value can be set to an integer between 1 and 20, inclusive. This value defaults to 16 if not specified.
     */
    automaticParticipantLimit?: number;
    /**
     * Sets the joining participant's display name. May be up to 64 characters long.
     */
    displayName?: string;
}
/**
 * SubscriptionMode determines how the SDK will subscribe to participants.
 */
export declare enum SubscriptionMode {
    /**
     * Automatic subscription mode means the SDK will automatically subscribe to up to 20 participants.
     * It prioritizes participants that have audio and video tracks unmuted and participants that are actively speaking.
     * TODO: Flesh out this description
     */
    Automatic = "AUTOMATIC",
    /**
     * Manual subscription mode means the SDK will *NOT* automatically subscribe to participants. In this mode you must
     * call [[RemoteParticipant.subscribe]] in order to start receiving media from participants. TODO: Flesh out this description
     */
    Manual = "MANUAL"
}
