export interface ITrackParams {
    tid: string;
    name: string;
    muted: boolean;
    source: string;
    height: number;
    width: number;
    type: TrackKind;
    metadata: Record<string, unknown>;
}
/**
 * TrackKind specifies the type of a track
 */
export declare enum TrackKind {
    /**
     * Audio track
     */
    Audio = 1,
    /**
     * Video track
     */
    Video = 2
}
/**
 * TrackSource specifies the source of a track.
 * This is not derived from a MediaStreamTrack property and is
 * intended to give you an easy way to differentiate track types.
 */
export declare enum TrackSource {
    /**
     * Camera source
     * A track containing webcam video
     */
    Camera = "camera",
    /**
     * Microphone source
     * A track containing microphone audio
     */
    Microphone = "microphone",
    /**
     * Screenshare source
     * A track containing screenshare video
     */
    Screenshare = "screenshare",
    /**
     * ScreenshareAudio source
     * A track containing screenshare audio
     */
    ScreenshareAudio = "screenshareaudio",
    /**
     * Other source
     * A track that explicitly doesn't match
     * one of our existing enums
     */
    Other = "other"
}
